<?php

namespace FiloBlu\ExtEbizmartsMailChimp\Model\Api;

use Magento\Framework\Exception\State\ExpiredException;
use Symfony\Component\Config\Definition\Exception\Exception;

class Customer extends \Ebizmarts\MailChimp\Model\Api\Customer
{

    protected $_countryFactory;
    
    public function __construct(
        \Ebizmarts\MailChimp\Helper\Data $helper,
        \Magento\Customer\Model\CustomerFactory $customerFactory,
        \Magento\Customer\Model\ResourceModel\Customer\CollectionFactory $collection,
        \Magento\Sales\Model\ResourceModel\Order\CollectionFactory $orderCollection,
        \Magento\Directory\Api\CountryInformationAcquirerInterface $countryInformation,
        \Magento\Customer\Model\Address $address,
        \Magento\Framework\Stdlib\DateTime\DateTime $date,
        \Magento\Directory\Model\CountryFactory $countryFactory
    ) {
    
        $this->_countryFactory = $countryFactory;
        parent::__construct($helper, $customerFactory, $collection, $orderCollection, $countryInformation, $address, $date);
    }
    

    /**
     * @param \Magento\Customer\Model\Customer $customer
     * @return array
     */
    protected function _buildCustomerData(\Magento\Customer\Model\Customer $customer)
    {
        $point = 0;
        $data = [];
        $data["id"] = $customer->getId();
        $data["email_address"] = $customer->getEmail() ? $customer->getEmail() : '';
        $data["first_name"] = $customer->getFirstname() ? $customer->getFirstname() : '';
        $data["last_name"] = $customer->getLastname() ? $customer->getLastname() : '';
        $data["opt_in_status"] = $this->getOptin();
        // customer order data
        $orderCollection = $this->_orderCollection->create();
        $orderCollection->addFieldToFilter('state', [
            ['neq',\Magento\Sales\Model\Order::STATE_CANCELED],
            ['neq',\Magento\Sales\Model\Order::STATE_CLOSED]])
            ->addAttributeToFilter('customer_id', ['eq' => $customer->getId()]);
        $totalOrders = 0;
        $totalAmountSpent = 0;
        /**
         * @var $customerOrder \Magento\Sales\Model\Order
         */
        foreach ($orderCollection as $customerOrder) {
            $totalOrders++;
            $totalAmountSpent += $customerOrder->getGrandTotal() - $customerOrder->getTotalRefunded()
                - $customerOrder->getTotalCanceled();
        }
        $data['orders_count']   = $totalOrders;
        $data['total_spent']    = $totalAmountSpent;
        $address = $customer->getDefaultBillingAddress();
        if ($address) {
            $customerAddress = [];
            if ($street = $address->getStreet()) {
                $street = $address->getStreet();
                if ($street[0]) {
                    $customerAddress["address1"] = $street[0];
                }
                if (count($street) > 1) {
                    $customerAddress["address2"] = $street[1];
                }
            }
            if ($address->getCity()) {
                $customerAddress["city"] = $address->getCity();
            }
            if ($address->getRegion()) {
                $customerAddress["province"] = $address->getRegion();
            }
            if ($address->getRegionCode()) {
                $customerAddress["province_code"] = $address->getRegionCode();
            }
            if ($address->getPostcode()) {
                $customerAddress["postal_code"] = $address->getPostcode();
            }
            if ($address->getCountryId()) {
//                $country = $this->_countryInformation->getCountryInfo($address->getCountryId());
//                $countryName = $country->getFullNameLocale();
                $country = $this->_countryFactory->create()->loadByCode($address->getCountryId());
                $customerAddress["country"] = $country->getName();
                $customerAddress["country_code"] = $address->getCountryId();
            }
            if (count($customerAddress)) {
                $data["address"] = $customerAddress;
            }
            //company
//                if ($address->getCompany()) {
//                    $data["company"] = $address->getCompany();
//                }
//                break;
//            }
//        }
        }
        return $data;
    }
}
